@@ -28,11 +28,11 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <tqregexp.h>
 
 // KDE
-#include <kaboutdata.h>
-#include <kapplication.h>
+#include <tdeaboutdata.h>
+#include <tdeapplication.h>
 #include <kdebug.h>
-#include <klocale.h>
-#include <kio/netaccess.h>
+#include <tdelocale.h>
+#include <tdeio/netaccess.h>
 #include <kstandarddirs.h>
 #include <kurl.h>
 
@@ -187,9 +187,9 @@ struct Generator::Private {
 		destURL.addPath(srcURL.filename());
 		
 		if (TQFile::exists(destURL.path())) {
-			KIO::NetAccess::del(destURL, mProgressDialog);
+			TDEIO::NetAccess::del(destURL, mProgressDialog);
 		}
-		bool ok=KIO::NetAccess::dircopy(srcURL, destURL, mProgressDialog);
+		bool ok=TDEIO::NetAccess::dircopy(srcURL, destURL, mProgressDialog);
 		if (!ok) {
 			logError(i18n("Could not copy theme"));
 			return false;
